import { BasicColumn, FormSchema } from '@/components/Table';
import { h, Ref } from 'vue';
import { Switch } from 'ant-design-vue';
import { setRoleStatus } from '@/api/system/role/role';
import { useMessage } from '@/hooks/web/useMessage';

type CheckedType = boolean | string | number;
export const columns: BasicColumn[] = [
  {
    title: '通知时间',
    dataIndex: 'createDate',
    width: 200,
    sorter: true,
  },
  {
    title: '通知规则',
    dataIndex: 'alarmRuleName',
    width: 180,
  },
  {
    title: '紧急程度',
    dataIndex: 'alarmLevel',
    width: 100,
  },
  {
    title: '资源类型',
    dataIndex: 'resourceType',
    width: 100,
  },
  {
    title: '触发方式',
    dataIndex: 'triggerType',
    width: 100,
  },
];
export const columnstab2: BasicColumn[] = [
  {
    title: '通知规则名称',
    dataIndex: 'alarmRuleName',
    width: 200,
  },
  {
    title: '资源类型',
    dataIndex: 'resourceType',
    width: 180,
  },
  {
    title: '紧急程度',
    dataIndex: 'alarmLevel',
    width: 100,
  },
  {
    title: '状态',
    dataIndex: 'status',
    width: 100,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'roleName',
    label: ' ',
    component: 'Input',
    componentProps: {
      placeholder: '请输入关键字',
    },
    colProps: { span: 4 },
  },
  // {
  //   field: 'alarmScope',
  //   label: ' ',
  //   component: 'Select',
  //   componentProps: {
  //     options: [
  //       { label: '全部通知', value: '1' },
  //       { label: '通知范围1', value: '2' },
  //       { label: '通知范围2', value: '3' },
  //     ],
  //     placeholder: '请选择通知规则范围',
  //     defaultValue: '1',
  //   },
  //   colProps: { span: 4 },
  // },
  {
    field: 'alarmRule',
    label: ' ',
    component: 'Select',
    componentProps: {
      options: [
        { label: '元数据变更', value: '元数据变更' },
        { label: '元数据处理', value: '元数据处理' },
      ],
      placeholder: '请选择通知规则',
    },
    colProps: { span: 4 },
  },
  {
    field: 'resourceType',
    label: ' ',
    component: 'Select',
    componentProps: {
      options: [
        { label: '数据加载', value: '1' },
        { label: '数据同步', value: '2' },
        { label: '工作流', value: '3' },
        { label: '标签', value: '4' },
        { label: '数据质量任务', value: '5' },
        { label: '落标检查任务', value: '6' },
        { label: '元数据变更', value: '7' },
        { label: '标准版本变更', value: '8' },
      ],
      placeholder: '请选择资源类型',
    },
    colProps: { span: 4 },
  },
  {
    field: 'alarmLevel',
    label: ' ',
    component: 'Select',
    componentProps: {
      options: [
        { label: '紧急', value: '紧急' },
        { label: '不紧急', value: '不紧急' },
      ],
      placeholder: '请选择紧急程度',
    },
    colProps: { span: 4 },
  },
];
export const searchFormSchematab2: FormSchema[] = [
  {
    field: 'roleName',
    label: ' ',
    component: 'Input',
    componentProps: {
      placeholder: '请输入关键字',
    },
    colProps: { span: 4 },
  },
  {
    field: 'resourceType',
    label: ' ',
    component: 'Select',
    componentProps: {
      options: [
        { label: '数据加载', value: '1' },
        { label: '数据同步', value: '2' },
        { label: '工作流', value: '3' },
        { label: '标签', value: '4' },
        { label: '数据质量任务', value: '5' },
        { label: '落标检查任务', value: '6' },
        { label: '元数据变更', value: '7' },
        { label: '标准版本变更', value: '8' },
      ],
      placeholder: '请选择资源类型',
    },
    colProps: { span: 4 },
  },
  {
    field: 'alarmLevel',
    label: ' ',
    component: 'Select',
    componentProps: {
      options: [
        { label: '紧急', value: '紧急' },
        { label: '不紧急', value: '不紧急' },
      ],
      placeholder: '请选择紧急程度',
    },
    colProps: { span: 4 },
  },
  {
    field: 'status',
    label: ' ',
    component: 'Select',
    componentProps: {
      options: [
        { label: '状态1', value: '状态1' },
        { label: '状态2', value: '状态2' },
      ],
      placeholder: '请选择状态',
    },
    colProps: { span: 4 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'alarmRuleName',
    label: '规则名称',
    component: 'Input',
    colProps: { span: 24 },
    rules: [
      {
        required: true,
        message: '请输入规则名称',
      },
    ],
  },
  {
    field: 'description',
    label: '描述',
    component: 'InputTextArea',
    colProps: { span: 24 },
  },
  {
    field: 'roleStatus',
    label: '规则状态',
    component: 'Switch',
    colProps: { span: 24 },
    defaultValue: false,
  },
  {
    field: 'resourceType',
    label: '资源类型',
    component: 'Select',
    colProps: { span: 24 },
    componentProps: {
      defaultValue: '数据加载',
      options: [
        { label: '数据加载', value: '1' },
        { label: '数据同步', value: '2' },
        { label: '工作流', value: '3' },
        { label: '标签', value: '4' },
        { label: '数据质量任务', value: '5' },
        { label: '落标检查任务', value: '6' },
        { label: '元数据变更', value: '7' },
        { label: '标准版本变更', value: '8' },
      ],
    },
  },
  //未解决问题:作用范围列未添加
  // {
  //   field: 'alarmRange',
  //   label: '作用范围',
  //   component: 'Select',
  //   colProps: { span: 24 },
  //   componentProps: {
  //     options: [
  //       { label: '元数据变更', value: '1' },
  //       { label: '元数据处理', value: '2' },
  //     ],
  //   },
  //   rules: [
  //     {
  //       required: true,
  //       message: '请选择作用范围',
  //     },
  //   ],
  // },
  {
    field: 'triggerType',
    label: '触发方式',
    component: 'CheckboxGroup',
    colProps: { span: 24 },
    componentProps: {
      defaultValue: ['1'],
      options: [
        { label: '运行失败', value: '1' },
        { label: '运行成功', value: '2' },
        { label: '开始运行', value: '3' },
        { label: '运行超时', value: '4' },
        { label: '源端元数据更新', value: '5' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择触发方式',
      },
    ],
  },
  {
    field: 'alarmType',
    label: '通知方式',
    component: 'CheckboxGroup',
    colProps: { span: 24 },
    componentProps: {
      defaultValue: ['1', '2'],
      options: [
        { label: '站内信', value: '1' },
        { label: '邮件', value: '2' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择通知方式',
      },
    ],
  },
  {
    field: 'message',
    label: '收件人',
    component: 'Select',
    colProps: { span: 12 },
    componentProps: {
      mode: 'multiple',
      options: [
        { label: '收件人1', value: '1' },
        { label: '收件人2', value: '2' },
        { label: '收件人3', value: '3' },
      ],
    },
    ifShow: ({ values }) => values.alarmType !== undefined && values.alarmType.includes('1'),
    required: ({ values }) => values.alarmType !== undefined && values.alarmType.includes('1'),
  },
  {
    field: 'email',
    label: '邮箱地址',
    component: 'InputTextArea',
    colProps: { span: 12 },
    componentProps: {
      defaultValue: '11111112222222@123321.123',
      placeholder: '多个邮件地址用;分隔符分割',
    },
    ifShow: ({ values }) => values.alarmType !== undefined && values.alarmType.includes('2'),
    required: ({ values }) => values.alarmType !== undefined && values.alarmType.includes('2'),
  },
  {
    field: 'alarmLevel',
    label: '紧急程度',
    component: 'Select',
    colProps: { span: 24 },
    componentProps: {
      options: [
        { label: '低', value: '1' },
        { label: '中', value: '2' },
        { label: '高', value: '3' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择紧急程度',
      },
    ],
  },
];
export const formSchema2: FormSchema[] = [
  {
    field: 'basicInformation',
    component: 'BasicTitle',
    label: '基本信息',
    componentProps: {
      // line: true,
      span: true,
    },
    colProps: {
      span: 24,
    },
  },
  {
    field: 'taskName',
    label: '任务名称',
    component: 'Input',
    defaultValue: '任务名称1',
    colProps: { span: 12 },
  },
  {
    field: 'createTime',
    label: '通知时间',
    component: 'Input',
    defaultValue: '2022-01-01 00:00:00',
    colProps: { span: 12 },
  },
  {
    field: 'alarmLevel',
    label: '紧急程度',
    component: 'Select',
    colProps: { span: 12 },
    componentProps: {
      options: [
        { label: '低', value: '1' },
        { label: '中', value: '2' },
        { label: '高', value: '3' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择紧急程度',
      },
    ],
  },
  {
    field: 'alarmRuleName',
    label: '通知规则',
    component: 'Input',
    colProps: { span: 12 },
  },
  {
    field: 'alarmsDetails',
    component: 'BasicTitle',
    label: '通知详情',
    componentProps: {
      // line: true,
      span: true,
    },
    colProps: {
      span: 24,
    },
  },
  {
    field: 'details',
    label: '详情:',
    component: 'InputTextArea',
    colProps: { span: 24 },
  },
  {
    field: 'ErrorCode',
    label: '错误码',
    component: 'Input',
    colProps: { span: 24 },
  },
];
