import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch, Button } from 'ant-design-vue';
import { getAllRoleList, setRoleStatus } from '@/api/system/role/role';
import { useMessage } from '@/hooks/web/useMessage';
import Icon from '@/components/Icon/Icon.vue';
import { setMenuStatus } from '@/api/system/menu/menu';
import { last } from 'xe-utils';

type CheckedType = boolean | string | number;
export const columns: BasicColumn[] = [
  {
    title: '菜单名称',
    dataIndex: 'menuName',
    width: 50,
    align: 'left',
    colProps: { span: 8 },
  },
];

export const ModelFormSchema: FormSchema[] = [
  //未解决问题: 无法为表单添加第三个按钮 导致无法添加测试连接按钮
  {
    field: 'agreement',
    component: 'RadioGroup',
    label: '邮箱服务协议',
    colProps: {
      span: 24,
    },
    componentProps: {
      options: [
        {
          label: 'SMTP',
          value: '1',
        },
        {
          label: 'SMTPS',
          value: '2',
        },
      ],
    },
  },
  {
    field: 'hostName',
    label: '主机名',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入主机名',
      },
    ],
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'port',
    label: '端口',
    component: 'InputNumber',
    rules: [
      {
        required: true,
        message: '请输入端口号',
      },
    ],
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'Username',
    label: '用户名',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入用户名',
      },
    ],
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'password',
    label: '密码',
    component: 'InputPassword',
    rules: [
      {
        required: true,
        message: '请输入密码',
      },
    ],
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'emailAddress',
    label: '发件邮箱地址',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入邮箱地址',
      },
    ],
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'linkTimeOut',
    label: '链接超时',
    component: 'Input',
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'TLS',
    label: 'TLS',
    component: 'Checkbox',
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'mailPrefix',
    label: '邮件前缀',
    component: 'Input',
    componentProps: {
      disabled: false,
    },
  },
  // 未解决问题:无法把按钮添加到表单已有的按钮中
  // {
  //   field: 'testLink',
  //   label: '测试链接',
  //   component: 'Button',
  //   componentProps: {
  //     type: 'primary',
  //     title: '测试链接',
  //   },
  // },
];
export const ModelFormSchema2: FormSchema[] = [
  // 未解决问题:原型文件没有短信配置页面截图!!

  {
    field: 'hostName',
    label: '主机名',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入主机名',
      },
    ],
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'port',
    label: '端口',
    component: 'InputNumber',
    rules: [
      {
        required: true,
        message: '请输入端口号',
      },
    ],
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'Username',
    label: '用户名',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入用户名',
      },
    ],
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'password',
    label: '密码',
    component: 'InputPassword',
    rules: [
      {
        required: true,
        message: '请输入密码',
      },
    ],
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'url',
    label: 'url地址',
    component: 'Input',
    componentProps: {
      disabled: false,
    },
    rules: [
      {
        required: true,
        message: '请输入url地址',
      },
    ],
  },
  {
    field: 'linkTimeOut',
    label: '链接超时',
    component: 'Input',
    componentProps: {
      disabled: false,
    },
  },
  {
    field: 'TLS',
    label: 'TLS',
    component: 'Checkbox',
    componentProps: {
      disabled: false,
    },
  },

  // 未解决问题:无法把按钮添加到表单已有的按钮中
  // {
  //   field: 'testLink',
  //   label: '测试链接',
  //   component: 'Button',
  //   componentProps: {
  //     type: 'primary',
  //     title: '测试链接',
  //   },
  // },
];
